import Swal from "sweetalert2";
import "sweetalert2/dist/sweetalert2.min.css";

import router from '@/router';

export class ErrorService {

  static onError(error) {
    const response = error;
    if (response && response.status === 403) {
      router.push({ name: '403Page'});
    }
    if (response && response.status >= 400 && response.status < 405) {

      const errorObj = response.data.detail ? response.data.detail : response.data;
      const messages = [];
      function recurse(obj) {
        for (const [key, value] of Object.entries(obj)) {
          if (typeof key === 'string' && typeof value === 'string') {
            messages.push(`<b>${key}:</b> ${value}`);
          } else if (typeof value === 'string') {
            messages.push(`${value}`);
          } else {
            recurse(value);
          }
        }
      }
      recurse(errorObj);

      Swal.fire({
        position: 'top-end',
        icon: 'error',
        title: `Erreur ${response.status}`,
        html: messages.join('\n'),
        showConfirmButton: false,
        timer: 3000
      });
    }
    return false;
  }

  static onSuccess(response, message) {
    if (response) {
      Swal.fire({
        position: 'top-end',
        heightAuto: false,
        icon: 'success',
        title: `${message}`,
        showConfirmButton: false,
        timer: 3000
      });
    }
    return false;
  }
}
